##  Prerequisites
  * Administrator access to SAP LeanIX.
  * Global administrator access to an SAP BTP cockpit that has the Cloud ALM API registered. To find this information in Cloud ALM, go to Administration > Landscape Management > Services and Systems. Search for and select Cloud ALM and go to the Additional Details section of the Details tab.
  * Additional requirements for SAP Private Cloud and SAP On-Premise discovery:
    * Onboarding to the New Innovation of Enhanced Maintenance Planner. This step enables the data flow from Landscape Information Service (LIS) to inbox to retrieve service data. For setup guidance, refer to [2921927 ![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https://me.sap.com/notes/2921927). Raise an incident to activate innovations for Managed Provisioning (MP).
    * All relevant customer numbers are linked in Cloud ALM (if more than one). Learn more in [3479708 ![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https://me.sap.com/notes/3479708) .
    * The system is enabled for automated updates. You can monitor the system status in SAP for Me at: https://me.sap.com/systemdata/view/<yourSystemNumber>. To activate or register the system for direct data transmission to the SAP Support Backbone, refer to:
      * [2863831 ![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https://me.sap.com/notes/2863831) – Perform an automated update with SAP Solution Manager or SAP Focused Run
      * [2855951 ![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https://me.sap.com/notes/2855951) – Perform a direct automatic upload without SAP Solution Manager or SAP Focused Run
Additionally, you can verify the upload status in the Landscape Information Service (LIS) with https://me.sap.com/landscapemap/000000000<yourSystemNumber>/checkResults.
